@@ -2,7 +2,8 @@
 #undef VERSION
 #undef AT_BINDIR
 #undef GETTEXT_PACKAGE
-#undef GDM_CONFIGDIR
+#undef GDM_DEFAULTS_CONF
+#undef GDM_CUSTOM_CONF
 #undef GDM_USER_PATH
 #undef HALT_COMMAND
 #undef REBOOT_COMMAND
