@@ -78,7 +78,7 @@ get_free_display (void)
 	serv_addr.sin_family = AF_INET;
 	serv_addr.sin_addr.s_addr = htonl (INADDR_LOOPBACK);
 
-	for (i = 20; i < 3000; i ++) {
+	for (i = 20; i < 3000; i++) {
 		struct stat s;
 		char buf[256];
 		FILE *fp;
@@ -498,6 +498,9 @@ main (int argc, char *argv[])
 	pidfile        = gdm_config_get_string (GDM_KEY_PID_FILE);
 	xnest          = gdm_config_get_string (GDM_KEY_XNEST);
 
+	/* At this point we are done using the socket, so close it */
+	gdmcomm_comm_close ();
+
 	/* complex and wonderous way to get the exec vector */
 	execvec = make_us_an_exec_vector (xnest);
 
