@@ -210,13 +210,18 @@ menu_position_func (GtkMenu           *menu,
 	*push_in = TRUE;
  }
 
- static void
- greeter_options_handler (GreeterItemInfo *item, GtkWidget *menubar)
- {
-	 gtk_menu_popup (GTK_MENU(gtk_menu_item_get_submenu(gtk_container_get_children(GTK_CONTAINER(menubar))->data)), 
-			 NULL, NULL, (GtkMenuPositionFunc)menu_position_func, 
-			 item, 0, gtk_get_current_event_time());
- }
+/*
+ * The button with this handler never appears in the F10 menu, so
+ * it can make use of callback data.
+ */
+static void
+greeter_options_handler (GreeterItemInfo *item, GtkWidget *menubar)
+{
+	gtk_menu_popup (GTK_MENU(gtk_menu_item_get_submenu(
+		        gtk_container_get_children(GTK_CONTAINER(menubar))->data)), 
+			NULL, NULL, (GtkMenuPositionFunc)menu_position_func, 
+			item, 0, gtk_get_current_event_time());
+}
 
 void
 greeter_item_create_canvas_item (GreeterItemInfo *item)
@@ -437,7 +442,7 @@ greeter_item_create_canvas_item (GreeterItemInfo *item)
 					NULL);
 
     /* cursor blinking is evil on remote displays, don't do it forever */
-    gdm_setup_blinking_entry (entry);
+    gdm_common_setup_blinking_entry (entry);
 
     break;
 
@@ -636,7 +641,7 @@ greeter_canvas_item_break_set_string (GreeterItemInfo *info,
 			while (i < n_chars) {
 				g_string_append_unichar (word, ch);
 				p = g_utf8_next_char (p);
-				i ++;
+				i++;
 
 				if (ch == '>') {
 					ch = g_utf8_get_char (p);
@@ -654,12 +659,12 @@ greeter_canvas_item_break_set_string (GreeterItemInfo *info,
 				in_current_row = 0;
 		}
 
-		in_current_row ++;
+		in_current_row++;
 		g_string_append_unichar (word, ch);
 
 		p = g_utf8_next_char (p);
-		i ++;
-		ia ++;
+		i++;
+		ia++;
 
 		/* eeek! */
 		if (ia >= n_attrs) {
@@ -667,7 +672,7 @@ greeter_canvas_item_break_set_string (GreeterItemInfo *info,
 				ch = g_utf8_get_char (p);
 				g_string_append_unichar (word, ch);
 				p = g_utf8_next_char (p);
-				i ++;
+				i++;
 			}
 			break;
 		}
